#!/usr/bin/env python
import sys
import numpy as np
np.set_printoptions(threshold=sys.maxsize)
import mandelbrot_ext as mandel
import matplotlib.pyplot as plt
import juliaplot as jp
import time



def mandelbrot_loop(im_width, im_height, xwidth, yheight, xmin, ymin, nitmax):
    zabsmax = 2.0
    maxval=0;
    oldmax=-100
    mm = np.zeros((im_width * im_height)) # 1D array
    for i in range(im_width * im_height): # over all elements in 1D
        # i = ix * im_width + iy: with i and im_width we can get ix, iy
        ix = int(i/im_width)   # 2D index i
        iy = i - ix * im_width # 2D index j
        nit = 0
        # mandelbrot-set changes the constant in z = z^2 + c
        # whereas the julia-set changes the z value and fixes c
        x = xmin + float(ix)*xwidth/im_width
        y = ymin + float(iy)*yheight/im_height
        c = complex(x, y)
        z = 0.0j;
        # Do the iterations
        mm[i] = mandel.calcz(z,c,zabsmax)
        if mm[i] == 1.0:
            mm[i] = 0.0;
        if mm[i] > oldmax:
            oldmax = mm[i]
            #print(oldmax)

        #else:
        #    mm[i] *= 255.0;
    #print(set(mm))
    mm = mm / oldmax
    return mm.reshape(im_width,im_height)


if __name__ == '__main__':
    file=''
    if len(sys.argv)>1:
        file = sys.argv[1]
        if ".pdf" in file:
            file = file.replace(".pdf","")


    #
    X = -0.5
    Y = 0.
    R = 1.0
    #
    #X = -0.748
    #Y = 0.1
    #R = 0.0014
    #
    #X = -0.925
    #Y = 0.266
    #R = 0.032
    #
    #X = -0.722
    #Y = 0.246
    #R = 0.019
    #
    #X = -0.7453
    #Y = 0.1127
    #R = 0.00065
    print("Mandelbrot set fractal generator\n")
    im_width = 1000
    im_height = 1000
    ymin,ymax = X-R, X+R
    xmin, xmax = Y-R, Y+R
    xwidth = xmax-xmin
    yheight = ymax - ymin
    nitmax = 10000
    title="Mandelbrot set fractal generator"
    tic = time.time()
    mm = mandelbrot_loop(im_width, im_height, yheight, xwidth, ymin, xmin, nitmax)
    toc = time.time()
    fig, ax = jp.plot(mm)
    jp.plotlabels(fig, ax, im_width, im_height, xmin,xmax,xwidth, ymin, ymax, yheight)    
    if file!='':
        plt.savefig(file+".pdf",bbox_inches='tight',dpi=100)
    plt.show()
    print("time",toc-tic)
